# Generated by Django 2.2 on 2021-05-30 06:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mfa', '0010_auto_20201110_0557'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user_keys',
            name='owned_by_enterprise',
            field=models.BooleanField(blank=True, default=None, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='User_Keys',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('username', models.CharField(max_length=50)),
                ('secret_key', models.CharField(max_length=15)),
                ('added_on', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
